@@ -1,27 +1,29 @@
 use serde::{Deserialize, Serialize};
 
-pub mod text;
-pub use text::Text;
-
-pub mod opt;
-pub use opt::Opt;
-
-pub mod opt_group;
-pub use opt_group::OptGroup;
-
 pub mod confirm;
-pub use confirm::{Confirm, ConfirmStyle};
-
 pub mod conversation_filter;
+pub mod opt;
+pub mod opt_group;
+pub mod text;
+
+#[doc(inline)]
+pub use confirm::{Confirm, ConfirmStyle};
+#[doc(inline)]
 pub use conversation_filter::ConversationFilter;
+#[doc(inline)]
+pub use opt::Opt;
+#[doc(inline)]
+pub use opt_group::OptGroup;
+#[doc(inline)]
+pub use text::Text;
 
 /// An Option or Option Group
 #[derive(Clone, Debug, Deserialize, Hash, PartialEq, Serialize)]
 #[serde(untagged)]
-pub enum OptOrOptGroup<M> {
-    Opt(Opt<M>),
-    OptGroup(OptGroup<M>),
+pub enum OptOrOptGroup<'a, M> {
+  Opt(Opt<'a, M>),
+  OptGroup(OptGroup<'a, M>),
 }
 
-crate::convert!(impl<M> From<Opt<M>> for OptOrOptGroup<M> => |o| OptOrOptGroup::Opt(o));
-crate::convert!(impl<M> From<OptGroup<M>> for OptOrOptGroup<M> => |o| OptOrOptGroup::OptGroup(o));
+crate::convert!(impl<'a, M> From<Opt<'a, M>> for OptOrOptGroup<'a, M> => |o| OptOrOptGroup::Opt(o));
+crate::convert!(impl<'a, M> From<OptGroup<'a, M>> for OptOrOptGroup<'a, M> => |o| OptOrOptGroup::OptGroup(o));
